function [rays,I] = traceto(myelement,rays,I),

% TRACETO call the correct functions to do the tracing.
% 
% [rays, I] = traceto(myelement,rays,I),
%
% assuming surface centered frame. 

        myelement = struct(myelement);        
        label = lower(myelement.type);
        
        switch(label)

          case  { 'asphere', } 

            Q = myelement.Q; R = myelement.R;
            info = [ -R/sqrt(1+Q) -R/sqrt(1+Q) -R ];
            [rays, I]     = traceto_ellipsoid(rays, info, myelement.aperture, I);
           
          case { 'ellipsoid','sphere' }
              
            [rays, I]     = traceto_ellipsoid(rays, myelement.abc, myelement.aperture, I);
                        
          case  { 'quadric' }

            % massage the data a bit
            info.Q         = myelement.Q;
            info.R         = myelement.R;
            info.aperture  = myelement.aperture;
            info.sense     = myelement.sense;  
            [rays, I]      = traceto_quadric(rays, info, I);
          
            
        case  { 'plane', 'pupil','image'}

            [ rays, I ] = traceto_plane(rays, myelement.aperture, I);
            if  isempty(rays)
                mdisp([ 'traceto: no rays traced to ' label ]);
                return
            end

        case 'index',
             error('optics definition faulty - cant trace an index element');

             % case  { 'toroid' }
             % case  { 'quadric' }
             % case  { 'bspline' }
             % case  { 'zernike' }
             
        otherwise
             error([ 'unknown optical element ' label ]);
             
    end

return
