function m = bend(strRef, m, n, n1, n2, varargin),

% BEND Refract or Reflect rays at the surface. Assumes that the  
% incoming ray (r) is the result of a trace to a particular surface (p). 
% 
%   m = BEND(strRef, m, n, n1, n2),
%
% 

% -------------------------------------------------------
% CODE CHANGES
% -------------------------------------------------------
%
% 28/10/04  eliminate complex rays (shifted to raytrak2)
% 
% 6/5/04    code required changes. 'plane' and 'pupil' require proper refraction routines - fixes not done.
%
% 29/1/04   changed InInfo  = [ myelement.position myelement.abc ] to InInfo  = [ 0 0 0 myelement.abc ]
% because the surfaces are now used in an element centered frame (and thereby dont required shifting 
% information.
% 

switch(strRef),
    case {'reflect'},
        m = reflect(m, n);
    case {'refract'},
        m = refract(m, n, n1, n2);
        nd = imag(m);
        if (any(nd~=0)), % internally reflected
            nd = (nd ~=0);
            m(nd,:) = reflect(m(nd,:), n(nd,:), n1);
        end            
    otherwise,
     error('(BEND) Reflection/Refraction Not Specified.');
end 

return