function [m_nPos, m_j] = trace_ellipsoid(nPos, nSlope, nAp, a, b, c)

% TRACE_ELLIPSOID intersect a origin centered conic surface
% with a ray (nPos, nSlope). 
%
% TRACE_ELLIPSOID(nPos, nSlope, nAp, A, B, C).  Here nPos is the position,
% nSlope is the ray slope, nAp is the aperture and (A, B, C) are the  
% semi-axes of the ellipsoid. The intersection point is returned as well as an index 
% into the rays that are remaining.
%
%
% NOTE : 
%       crude root detection employed.

if (nargin == 1),
    if (strcmp(nPos, 'type')),
        m_nPos = 'analytic'; m_j = [];
        return
    end
    error('(TRACE_ELLIPSOID) Error in invocation.');
end


% internal index
j = (1:size(nPos, 1))';  
m_j = []; m_nPos = [];


% main intersection 
X0 = nPos; M = nSlope; DXC = X0; 
DXC(:,3) = DXC(:,3) - c;

A  = [ a b c ];
A  = (1./(A.^2))';

a0  = (M.*M)*A;
b0  = 2*(M.*DXC)*A;
c0  = (DXC.*DXC)*A - 1;

d0   = b0.^2 - 4*a0.*c0;
ndx = (d0 < 0);
if (any(ndx)), 
       if (all(ndx)),
           warning('(TRACETO_ELLIPSOID) returning early.');
           return
       end 
       % remaining rays
       ndx = ~ndx;
       a0 = a0(ndx); b0 = b0(ndx); d0 = d0(ndx); % c=c(ndx);
       M = M(ndx, :); X0 = X0(ndx, :);
       j = j(ndx);
end

% choose correct root !
l1 = (-b0 + sqrt(d0))./(2*a0);
l2 = (-b0 - sqrt(d0))./(2*a0);

% negative roots only.
ndx = (l1 < 0)&(l2 < 0);
if (any(ndx))
    if (all(ndx)),
      warning('(TRACETO_ELLIPSOID) returning early.');
      return
    end
    
    warning('(TRACETO_CONIC) rays point away from surface. discarding.\n');
    % remaining 
    ndx    = ~ndx;
    X0 = X0(ndx, :); M = M(ndx, :); 
    l1 = l1(ndx); l2 = l2(ndx);
    j  = j(ndx);
end 

% c > 0, z0 > 0 [w0 < 0]
z0 = X0(:,3);
ndx = (c*M < 0);
if (any(ndx)),
    l(ndx)  = max([l1(ndx)' ; l2(ndx)']);
end 
ndx = ~ndx;
if (any(ndx)),
    l(ndx) = min([l1(ndx)' ; l2(ndx)']);   
end 
l = l(:);

% send to surface 
l  = l(:,[1 1 1]);
X0 = M.*l + X0;
r  = sqrt(X0(:,1).^2 + X0(:,2).^2 );
ndx  = (r <= nAp);
if   any(ndx),
     if (all(ndx)),
        m_j      = j(ndx);
        m_nPos   = X0(ndx,:);
        return
     end 
end

% unprocessed-rays.
error('(TRACETO_ELLIPSOID) Error. Rays remain unprocessed.');
return