function [m_nPos, m_j] = trace_prk(nPos, nSlope, nAp, etol, varargin)

% TRACE_PRK intersect any ray (nPos, nSlope) surface that 
% has a centered representation using a numeric approach. 
%
% TRACE_PRK(strFn, nPos, nSlope, nAp, ...).  Here nPos is the position,
% nSlope is the ray slope, nAp is the aperture. 
% The intersection point is returned as well as an index 
% into the rays that are remaining.
% 
% EXAMPLE 
%
%   R1 = 8; R2 = 6; r1 = 2.5; r2 =3.5; etol = 1e-9;
%   [nPos, nSlope] = createray([0 0 -10],[0 1 0]); 
%   [nPos, j] = trace_PRK(nPos, nSlope, nAp, etol, R1, R2, r1, r2);
% 


if (nargin == 1),
    if (strcmp(nPos, 'type')),
        m_nPos = 'numeric'; m_j = [];
        return
    end
    error('(TRACE_PRK) Error in invocation.');
end

[m_nPos, m_j] = trace_general('prk', nPos, nSlope, nAp, etol, varargin{:});
return
