function [m_nPos, m_j] = trace_toric(nPos, nSlope, nAp, etol, varargin)

% TRACE_TORIC intersect any ray (nPos, nSlope) surface that 
% has a centered representation using a numeric approach. 
%
% TRACE_TORIC(strFn, nPos, nSlope, nAp, ...).  Here nPos is the position,
% nSlope is the ray slope, nAp is the aperture and (CV, CC) are conic 
% arguments. The intersection point is returned as well as an index 
% into the rays that are remaining.
% 
% Example 
%
%   Rx = 7.5; Ry = 7; nAp =4; etol = 1e-9;
%   [nPos, nSlope] = createray([0 0 -10],[0 1 0]); 
%   [nPos, j] = trace_toric(nPos, nSlope, nAp, etol, Rx, Ry);
% 

if (nargin == 1),
    if (strcmp(nPos, 'type')),
        m_nPos = 'numeric'; m_j = [];
        return
    end
    error('(TRACE_TORIC) Error in invocation.');
end

[m_nPos, m_j] = trace_general('toric', nPos, nSlope, nAp, etol, varargin{:});

return
