function [x, y] = pImg2Obj(S, x, y);

% PIMG2OBJ Paraxial Image Space Point to Object Space  
%
% PIMG2OBJ(S, x, y). Determine the object space 
% conjugate to the image point (x,y).  That point (x,y) 
% is given w.r.t. the back vertex plane.  The output 
% points will be w.r.t. to the front vertex plane 
% typical input object will have x < 0 two arbitrary rays.
%
% PIMG2OBJ(S, x).  A default object height of y = 0 is used in this 
% case.

if (nargin == 2),
    y = 0;
end

% use two rays 
y  = [ 0 -tan(pi/4) ; y y ];
T  = [ 1 0 ; -x 1 ];        % transfer rays to FVP
y  = inv(S)*T*y;                 % put through system
x  = -(y(2,1)-y(2,2))/(y(1,1)-y(1,2));
y  = y(1,1)*x + y(2,1);
return
