function r = rayloc(p, etol, s0, x0),

% RAYLOC Determine a ray object that will give a set of rays 
% emanating from s0 that passes through system p to the source 
% point s0. 
%
% r = RAYLOC(p, etol, s0, x0). Here p is the lens prescription, 
% etol is the error tolerance, s0 is a matrix of source points, 
% and x0 is the desired target for the ray.
%

% initial target position on origin plane
t1 = s0; t1(:,3) = 0;

% input rays 
[t0, fe] = vpowellxy(@mTarg, t1, etol/sqrt(2), [ t1 s0 x0  ], p);
r  = ray('AIM-XYZ', s0, t0);

% r  = trace(r, p);
% r  = trans(r, x0(:,3));
% x1 = get(r, 'position');
% e = vnorm(x0(:,1:2) - x1(:,1:2));
% keyboard;
return 

function e = mTarg(x0, phi, n, varargin),
    p  = varargin{1};    
    t1 = phi(:,1:3);    % current target
    s0 = phi(:,4:6);    % source 
    t0 = phi(:,7:9);    % target
    t1(:, n) = x0;
    
    r = ray('AIM-XYZ', s0, t1); 
    nX = s0*nan; n0 = length(r);
    
    [r, j] = trace(r, p);
    r = trans(r, t0(:,3));
    nX(j,:) = get(r, 'position');
    
    e    = nX(:,n)-t0(:,n);
return